@@ -2,6 +2,7 @@
 
 from __future__ import annotations
 from typing import Literal, Sequence
+import math
 
 from ..segments import Segment, SegmentArrow, SegmentCircle, SegmentArc, SegmentPoly
 from .elements import Element, Element2Term
@@ -26,20 +27,50 @@ class Arrow(Line):
     '''
     def __init__(self, *d,
                  double: bool=False,
-                 headwidth: float=0.15, headlength: float=0.2,
+                 headwidth: float=0.2, headlength: float=0.25,
                  **kwargs):
         super().__init__(*d, **kwargs)
-        self.segments.append(SegmentArrow((-.3, 0), (0, 0),
+        self.double = double
+        self.headlength = headlength
+        self.headwidth = headwidth
+        self.segments.append(SegmentArrow((-headlength, 0), (0, 0),
                                           ref='end',
                                           headwidth=headwidth,
                                           headlength=headlength))
-        if double:
-            self.segments.append(SegmentArrow((0, 0), (-.3, 0),
+        if self.double:
+            self.segments.append(SegmentArrow((headlength, 0), (0, 0),
                                               ref='start',
                                               headwidth=headwidth,
                                               headlength=headlength))
         # Explicitly define center so reverses work
         self.anchors['center'] = (0, 0)
+        
+    def _place(self, xy, theta, **dwgparams):
+        ''' Shorten the underlying line so it doesn't stick out
+            from arrowhead
+        '''
+        result = super()._place(xy, theta, **dwgparams)
+        line = self.segments[0]  # The base line which needs to be shortened
+        xy1 = line.path[0]
+        xy2 = line.path[-1]
+        dx = xy2[0] - xy1[0]
+        dy = xy2[1] - xy1[1]
+        theta = math.atan2(dy, dx)
+        newhead = xy2
+        newtail = xy1
+        reverse = self._cparams.get('reverse')
+
+        if reverse or self.double:
+            newtail = (xy1[0] + self.headlength * math.cos(theta),
+                       xy1[1] + self.headlength * math.sin(theta))
+        
+        if (not reverse) or self.double:
+            newhead = (xy2[0] - self.headlength * math.cos(theta),
+                       xy2[1] - self.headlength * math.sin(theta))
+            
+        line.path[0] = newtail
+        line.path[-1] = newhead
+        return result
 
 
 class LineDot(Line):
@@ -280,8 +311,34 @@ class CurrentLabelInline(Element):
         return self
 
 
-class LoopCurrent(Element):
-    ''' Loop current label, for mesh analysis notation
+class LoopArrow(Element):
+    ''' Loop arrow, for mesh analysis notation
+
+        Args:
+            direction: loop direction 'cw' or 'ccw'
+            theta1: Angle of start of loop arrow
+            theta2: Angle of end of loop arrow
+            width: Width of loop
+            height: Height of loop
+    '''
+    def __init__(self, direction: Literal['cw', 'ccw']='cw',
+                 theta1: float=35, theta2: float=-35,
+                 width: float=1.0, height: float=1.0, **kwargs):
+        super().__init__(**kwargs)
+
+        self.segments.append(SegmentArc(
+            (0, 0), arrow=direction, theta1=theta1, theta2=theta2,
+            width=width, height=height))
+
+        self.params['lblloc'] = 'center'
+        self.params['lblofst'] = 0
+        self.params['theta'] = 0
+        self.anchors['center'] = (0, 0)
+
+
+class LoopCurrent(LoopArrow):
+    ''' Loop current label, for mesh analysis notation,
+        placed within a box of 4 existing elements.
 
         Args:
             elm_list: List of 4 elements surrounding loop, in
@@ -289,14 +346,12 @@ class LoopCurrent(Element):
             direction: loop direction 'cw' or 'ccw'
             theta1: Angle of start of loop arrow
             theta2: Angle of end of loop arrow
-            width: Width of loop
-            height: Height of loop
+            pad: Distance from elements to loop
     '''
     def __init__(self, elm_list: Sequence[Element]=None,
                  direction: Literal['cw', 'ccw']='cw',
                  theta1: float=35, theta2: float=-35,
                  pad: float=0.2, **kwargs):
-        super().__init__(**kwargs)
         assert elm_list is not None
         bbox1 = elm_list[0].get_bbox(transform=True, includetext=False)
         bbox2 = elm_list[1].get_bbox(transform=True, includetext=False)
@@ -309,15 +364,7 @@ class LoopCurrent(Element):
         center = ((left+rght)/2, (top+bot)/2)
         width = rght - left
         height = top - bot
-
-        self.segments.append(SegmentArc(
-            (0, 0), arrow=direction, theta1=theta1, theta2=theta2,
-            width=width, height=height))
-
-        self.params['lblloc'] = 'center'
-        self.params['lblofst'] = 0
-        self.params['theta'] = 0
-        self.anchors['center'] = (0, 0)
+        super().__init__(direction, theta1, theta2, width, height, **kwargs)
         self._userparams['at'] = center
 
 
